KARANAGE-tools
==============

`karanage-tools` is thez generic tools to interact with the server REST

[Git interface...](https://gitea.atria-soft.org/kangaroo-and-rabbit/karanage)



git repository
--------------

https://gitea.atria-soft.org/kangaroo-and-rabbit/karanage

Installation
------------

Requirements: ``Python >= 3`` and ``pip``

Just run:
```
pip3 install karanage-tools
```

developpement for karanage-tools:
```
git clone https://gitea.atria-soft.org/kangaroo-and-rabbit/karanage
cd karanage/client/python/karanage-tools
./setup.py develop --user
```

Documentation
-------------



License (MPL v2.0)
---------------------

Licensed under the Mozilla Public License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.mozilla.org/en-US/MPL/2.0/

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

